import { DomainModuleLink, IModuleAssociation, IModuleLink, IRelatedModule, UUID } from 'bf-types';
import { ValidModuleName } from '../Types';
/**
 * Create a new module link object
 *
 * This function provides type safety for the moduleName parameter. It ensures that
 * the module name is one the allowed module names. Because of that, it should be used whenever
 * a new module link is needed.
 *
 * @param moduleName The name of the module this link references
 * @param moduleId The ID of the Entity in the module this link references
 */
export declare function moduleLink(moduleName: ValidModuleName, moduleId: UUID): DomainModuleLink<ValidModuleName>;
/**
 * Create a new module association object
 *
 * This function provides type safety for the moduleName parameter. Because of that, it should
 * be used whenever a new module association is needed.
 *
 * @param moduleName The name of the module this association references
 * @param moduleId The ID of the Entity in the module this association references
 * @param id An optional ID to specify for this module association
 */
export declare function moduleAssociation(moduleName: ValidModuleName, moduleId: UUID, id?: UUID): IModuleAssociation;
/**
 * Create a new related module object
 *
 * This function provides type safety for the moduleName parameter. Because of that, it should
 * be used whenever a new related module is needed.
 *
 * @param moduleName The name of the module this related module object references
 * @param moduleId The ID of the Entity in the module this module object references
 * @param moduleTitle The title of the Entity in the module this module object references
 */
export declare function relatedModule(moduleName: ValidModuleName, moduleId: UUID, moduleTitle: string): IRelatedModule;
/**
 * Creates a new module link with an empty string for each field
 */
export declare function emptyModuleLink(): IModuleLink;
/**
 * Creates a new module link that is meant to be used as a placeholder
 */
export declare function placeholderModuleLink(moduleId?: string): IModuleLink;
/**
 * Creates a new related module with an empty string for each field
 */
export declare function emptyRelatedModule(): IRelatedModule;
