"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toUpperSnakeCase = exports.toLowerSnakeCase = exports.toUpperFirstLetter = exports.toLowerFirstLetter = exports.toUpperCamel = exports.toLowerCamel = exports.toDisplay = exports.formatDecimal = exports.numberWithCommas = exports.formatFloat = void 0;
const decimal_js_1 = require("decimal.js");
const voca_1 = require("voca");
/* ~~~ General String Functions ~~~ */
function formatFloat(value, decimalPlaces) {
    let numberValue = NaN;
    if (!decimalPlaces) {
        numberValue = Number(value);
        if (Number.isNaN(numberValue)) {
            numberValue = 0;
        }
        return String(numberValue);
    }
    numberValue = new decimal_js_1.Decimal(Number(value)).toDP(decimalPlaces).toNumber();
    if (Number.isNaN(numberValue)) {
        numberValue = 0;
    }
    return numberValue.toFixed(decimalPlaces);
}
exports.formatFloat = formatFloat;
function numberWithCommas(str) {
    return str.replace(/\B(?=(\d{3})+(?!\d))/g, ',');
}
exports.numberWithCommas = numberWithCommas;
function formatDecimal(value, decimalPlaces = 2) {
    const rounded = formatFloat(value, decimalPlaces);
    const chunks = rounded.split('.');
    if (chunks.length < 2) {
        return numberWithCommas(rounded);
    }
    return `${numberWithCommas(chunks[0])}.${chunks[1]}`;
}
exports.formatDecimal = formatDecimal;
function toDisplay(str) {
    const split = str.replace(/_/g, ' ').toLocaleLowerCase().split(' ');
    const toUpper = split.map((s) => toUpperFirstLetter(s));
    return toUpper.join(' ');
}
exports.toDisplay = toDisplay;
function toLowerCamel(str) {
    return voca_1.camelCase(str);
}
exports.toLowerCamel = toLowerCamel;
function toUpperCamel(str) {
    return voca_1.chain(str).camelCase().capitalize().value();
}
exports.toUpperCamel = toUpperCamel;
function toLowerFirstLetter(str) {
    return voca_1.decapitalize(str);
}
exports.toLowerFirstLetter = toLowerFirstLetter;
function toUpperFirstLetter(str) {
    return voca_1.capitalize(str);
}
exports.toUpperFirstLetter = toUpperFirstLetter;
function toLowerSnakeCase(str) {
    return voca_1.snakeCase(str);
}
exports.toLowerSnakeCase = toLowerSnakeCase;
function toUpperSnakeCase(str) {
    return voca_1.chain(str).snakeCase().upperCase().value();
}
exports.toUpperSnakeCase = toUpperSnakeCase;
