"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const bf_types_1 = require("bf-types");
const system_1 = require("../system");
function multitool() {
    let api = null;
    function getApi() {
        if (!api) {
            api = system_1.default.getLibModule(system_1.LibModule.API);
        }
        return api;
    }
    function executeCommand(command) {
        return __awaiter(this, void 0, void 0, function* () {
            const results = yield getApi().post('core/multitoolCommand/command/execute', {
                command,
            });
            if (!Array.isArray(results) || results.length < 1) {
                const result = {
                    action: bf_types_1.MultitoolCommandAction.CREATED,
                    result: bf_types_1.MultitoolCommandResult.FAILED,
                    reason: 'no response was given',
                };
                return result;
            }
            return results[0];
        });
    }
    function executeCommands(commands) {
        return __awaiter(this, void 0, void 0, function* () {
            const results = yield getApi().post('core/multitoolCommand/command/execute', {
                command: commands.join('\n'),
            });
            if (!Array.isArray(results) || results.length < 1) {
                const result = {
                    action: bf_types_1.MultitoolCommandAction.CREATED,
                    result: bf_types_1.MultitoolCommandResult.FAILED,
                    reason: 'no response was given',
                };
                return [result];
            }
            return results;
        });
    }
    function isCommandFailedResult(result) {
        return result.result === bf_types_1.MultitoolCommandResult.FAILED;
    }
    function isCommandSuccessResult(result) {
        return result.result === bf_types_1.MultitoolCommandResult.SUCCESS;
    }
    function runScript(script) {
        return getApi().post('core/multitoolCommand/script/run', {
            script,
        });
    }
    return Object.freeze({
        executeCommand,
        executeCommands,
        isCommandFailedResult,
        isCommandSuccessResult,
        runScript,
    });
}
exports.default = system_1.default.sealModule(multitool());
