"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.proxyWrap = exports.makeCallable = void 0;
function makeCallable(func, object) {
    Object.assign(func, object);
    return func;
}
exports.makeCallable = makeCallable;
function intercept(wrapper) {
    return (target, property) => {
        if (target[property]) {
            if (wrapper[property]) {
                const propertyType = typeof wrapper[property];
                if (propertyType === 'function') {
                    wrapper[property](...arguments);
                }
            }
            return target[property];
        }
        else {
            if (wrapper[property]) {
                return wrapper[property];
            }
            throw new Error('Tried to access an unititialized property.');
        }
    };
}
/**
 * Wrap an object in a proxy
 *
 * If a wrapper is supplied, each of its properties will be added to the proxy.
 * If a property is a function on the wrapper and target, the wrapper's function
 * will be invoked and then the target's will be.
 * If the proxy encounters a property that does not exist on the target or the
 * wrapper, it will throw an error.
 *
 * @param target The object what will be wrapped in a proxy
 * @param wrapper An optional object whose properties will be added to the proxy
 */
function proxyWrap(target, wrapper) {
    const proxy = new Proxy(target, {
        get: intercept(wrapper || {}),
        set() {
            throw new Error('Tried to update a readonly object.');
        },
    });
    return [target, proxy];
}
exports.proxyWrap = proxyWrap;
